@@ -1,5 +1,4 @@
 #include "screenshot.h"
-#include <gdk/gdkx.h>
 #include "io-png.h"
 
 #define SCALE_WIDTH 640
@@ -45,7 +44,7 @@ screenshot_grab (const gchar *filename)
 	g_return_val_if_fail (filename != NULL, FALSE);
 
 	/* Say cheese! */
-	root = GDK_ROOT_PARENT ();
+	root = gdk_get_default_root_window ();
 	gdk_window_get_size (root, &width, &height);
 			
 	buf = gdk_pixbuf_get_from_drawable (NULL, root, NULL,
