@@ -37,6 +37,7 @@
 #include <libgnome/libgnome.h>
 #include "bg-ext-handler.h"
 #include "bg-config-gui.h"
+#include <preferences.h>
 
 static MtmResult bg_plugin_theme_activate  (MtmExtHandler *handler, MtmExt *theme);
 static gchar *   bg_plugin_theme_find      (MtmExtHandler *handler, const gchar *name, gboolean is_root);
@@ -50,125 +51,67 @@ static gchar *bg_plugin_get_ext_version (MtmExtHandler *handler);
 static gboolean bg_plugin_version_is_compat (MtmExtHandler *handler,
 	gchar *ver1, gchar *ver2);
 
-	
+#define DGB "/desktop/gnome/background/"
+
 static MtmResult
 bg_plugin_theme_activate (MtmExtHandler *handler, MtmExt *theme)
 {
-	char *filename;
-	char *gnomedir;
-	char *installed = NULL;
-	BgConfig *config;
-	char *tmp;
+	BGPreferences *config;
+	GConfChangeSet *cs;
+	gchar *tmp;
 	
 	g_return_val_if_fail (handler != NULL, MTM_GENERAL_ERROR);
-	
-	gnomedir = g_strconcat (g_get_home_dir (), "/.gnome", NULL);
-	
-	if (mtm_check_dir (gnomedir) != MTM_OK)
-	{
-		g_free (gnomedir);
-		return MTM_NO_ACCESS;
-	}
-	
-	if (theme && theme->file)
-		installed = theme->file;
 
 	if (theme)
 		config = bg_ext_handler_get_config (BG_EXT_HANDLER (handler));
 	else
-	{
-		config = g_new0 (BgConfig, 1);
-		config->color1.red = 0x3d << 8;
-		config->color1.green = 0x71 << 8;
-		config->color1.blue = 0xaa << 8;
-		config->gradient = FALSE;
-	}
+		config = BG_PREFERENCES (bg_preferences_new ());
+
+	cs = gconf_change_set_new ();
+	gconf_change_set_set_bool (cs, DGB "enabled", config->enabled);
+	gconf_change_set_set_int (cs, DGB "wallpaper-type", config->wallpaper_type);
+	gconf_change_set_set_string (cs, DGB "wallpaper-filename", config->wallpaper_filename);
 	
-	tmp = config->filename;
-
-	if (installed)
-		config->filename = installed;
-	else
-		config->filename = "none";
-
-	filename = g_strconcat (gnomedir, "/", "Background", NULL);
-	bgconfig_save (config, filename); 
-
-	config->filename = tmp;
+	tmp = g_strdup_printf ("#%02x%02x%02x",
+		config->color1->red >> 8,
+		config->color1->green >> 8,
+		config->color1->blue >> 8);
+	gconf_change_set_set_string (cs, DGB "color1", tmp);
+	g_free (tmp);
 	
-	g_free (filename);	
-	g_free (gnomedir);
+	tmp = g_strdup_printf ("#%02x%02x%02x",
+		config->color2->red >> 8,
+		config->color2->green >> 8,
+		config->color2->blue >> 8);
+	gconf_change_set_set_string (cs, DGB "color2", tmp);
+	g_free (tmp);
+
+	gconf_change_set_set_int (cs, DGB "orientation", config->orientation);
+	gconf_client_commit_change_set (gconf_client_get_default (), cs, TRUE, NULL);
 
 	if (!theme)
-		bgconfig_destroy (config);
-
+		g_object_unref (G_OBJECT (config));
 	return MTM_OK;
 }
 
+
 static MtmResult bg_plugin_update_ext (MtmExtHandler *handler)
 {
-	gchar *filename;
-	BgConfig *config;
-	gchar *command;
-	gchar *bgfile;
-	
-	g_return_val_if_fail (handler != NULL, MTM_GENERAL_ERROR);
-	filename = g_strconcat (g_get_home_dir (), "/.gnome/Background", NULL);
-	config = bgconfig_load (filename);
-	
-	if (config->filename)
-		bgfile = config->filename;
-	else
-		bgfile = "none";
-
-#ifdef NEW_CAPPLET
-	system ("background-properties-capplet --get-legacy"); 
-
-	command = g_strdup_printf ("background-properties-capplet -b \"%s\" --init-session-settings",
-		bgfile);
-#else
-	command = g_strdup_printf ("background-properties-capplet -b \"%s\" --init-session-settings",
-		bgfile);
-#endif
-
-	system (command);
-	g_free (command);
-
-	bgconfig_destroy (config);
-	g_free (filename);
-
+	gconf_client_suggest_sync (gconf_client_get_default (), NULL);
 	return MTM_OK;
 }
 
 static gchar *
 bg_plugin_get_current_theme (MtmExtHandler *handler)
 {
-	char *filename;
-	gboolean def;
-	
-	gnome_config_pop_prefix ();
-	filename = gnome_config_get_string_with_default (
-		"/Background/Default/wallpaper=none", &def);
-	if (def || (filename && strcmp (filename, "none") == 0))
-	{	
-		g_free (filename);
-		filename = NULL;
-	}
-
-	return filename;
+	return gconf_client_get_string (gconf_client_get_default (), DGB "wallpaper-filename", NULL);
 }
 
+#undef DGB
+
 static gboolean
 bg_plugin_ext_is_installed (MtmExtHandler *handler)
 {
-	FILE *pipe;
-
-	g_return_val_if_fail (handler != NULL, FALSE);
-	
-	pipe = popen ("background-properties-capplet --version", "r");
-	if (!pipe)
-		return FALSE;
-	pclose (pipe);
 	return TRUE;
 }
 
@@ -197,24 +140,7 @@ bg_plugin_theme_find (MtmExtHandler *handler, const gchar *name, gboolean is_roo
 static gchar *
 bg_plugin_get_ext_version (MtmExtHandler *handler)
 {
-	FILE *pipe;
-	char ver[1000];
-	char *str;
-	char *ret;
-	int len;
-
-	g_return_val_if_fail (handler != NULL, NULL);
-
-	pipe = popen ("background-properties-capplet --version", "r");
-	if (!pipe)
-		return NULL;
-	fgets (ver, 1000, pipe);
-	pclose (pipe);
-	str = strstr (ver, "background-properties ");
-	len = strlen ("background-properties ");
-	ret = g_strdup (str + len);
-	ret = g_strchomp (ret);
-	return ret;
+	return NULL;
 }
 
 static gboolean
