@@ -13,7 +13,8 @@ typedef struct _BgExtHandlerPrivate BgExtHandlerPrivate;
 typedef struct _BgExtHandlerClass BgExtHandlerClass;
 
 #include <mtm/mtm-ext-handler.h>
-#include "editor.h"
+#include <gdk/gdktypes.h>
+#include <preferences.h>
 
 struct _BgExtHandler
 {
@@ -31,6 +32,6 @@ GtkType bg_ext_handler_get_type (void);
 
 BgExtHandler* bg_ext_handler_new (MtmEnv *env);
  
-BgConfig* bg_ext_handler_get_config (BgExtHandler *handler);
+BGPreferences* bg_ext_handler_get_config (BgExtHandler *handler);
 
 #endif /* __BG_EXT_HANDLER_H__ */
